@@ -22,6 +22,7 @@ import logging
 
 import panucci
 from panucci import services
+from panucci import util
 
 class BasePlayer(services.ObservableService):
     """ The player base class, this can't be used directly because most of
@@ -82,10 +83,8 @@ class BasePlayer(services.ObservableService):
                           Eg. file:///mnt/music/some-file.ogg
             Returns: Nothing
         """
-        if uri.startswith('/'):
-            uri = 'file://' + uri
-        self.current_uri = uri
-        return self._load_media(uri)
+        self.current_uri = util.file_to_url(uri)
+        return self._load_media(self.current_uri)
 
     def pause(self):
         """ Pauses playback.
@@ -125,6 +124,12 @@ class BasePlayer(services.ObservableService):
         """
         return self._seek(position)
 
+    def get_volume_level(self):
+        return self._get_volume_level()
+
+    def set_volume_level(self, percent):
+        self._set_volume_level(percent)
+
     #############################################
     # Generic Functions
 
