@@ -133,33 +133,14 @@ class PanucciGUI(object):
                     self.handle_headset_button)
             system_bus = dbus.SystemBus()
 
-            # Monitor connection state of BT headset
-            # I haven't seen this option before "settings.play_on_headset"
             PATH = '/org/freedesktop/Hal/devices/computer_logicaldev_input_1'
-            def handler_func(device_path):
-                if device_path == PATH and settings.play_on_headset and not self.playlist.player.playing:
-                    self.playlist.player.play()
-            system_bus.add_signal_receiver(handler_func, 'DeviceAdded', \
-                    'org.freedesktop.Hal.Manager', None, \
-                    '/org/freedesktop/Hal/Manager')
-            # End Monitor connection state of BT headset
+            # Monitor connection state of BT headset
+            system_bus.add_signal_receiver(self.handle_connection_state, 'DeviceAdded', \
+                    'org.freedesktop.Hal.Manager', None, '/org/freedesktop/Hal/Manager')
 
             # Monitor BT headset buttons
-            def handle_bt_button(signal, button):
-                # See http://bugs.maemo.org/8283 for details
-                if signal == 'ButtonPressed':
-                    if button == 'play-cd':
-                        self.playlist.player.play_pause_toggle()
-                    elif button == 'pause-cd':
-                        self.playlist.player.pause()
-                    elif button == 'next-song':
-                        self.__player_tab.do_seek(self.config.getint("options", "seek_short"))
-                    elif button == 'previous-song':
-                        self.__player_tab.do_seek(-1*self.config.getint("options", "seek_short"))
-
-            system_bus.add_signal_receiver(handle_bt_button, 'Condition', \
+            system_bus.add_signal_receiver(self.handle_bt_button, 'Condition', \
                     'org.freedesktop.Hal.Device', None, PATH)
-            # End Monitor BT headset buttons
 
         self.main_window.connect('key-press-event', self.on_key_press)
         self.playlist.register( 'file_queued', self.on_file_queued )
@@ -174,10 +155,10 @@ class PanucciGUI(object):
         # this should be done when the gui is ready
         self.playlist.init(filepath=filename)
 
-        pos_int, dur_int = self.playlist.player.get_position_duration()
+        pos_int, dur_int = self.playlist.get_position_duration()
         # This prevents bogus values from being set while seeking
         if (pos_int > 10**9) and (dur_int > 10**9):
-            self.set_progress_callback(pos_int, dur_int)
+            self.__player_tab.set_progress_callback(pos_int, dur_int)
 
         gtk.main()
 
@@ -187,6 +168,8 @@ class PanucciGUI(object):
         self.action_open.connect('activate', self.open_file_callback)
         self.action_open_dir = gtk.Action('open_dir', _('Add Folder'), _('Open a directory'), gtk.STOCK_OPEN)
         self.action_open_dir.connect('activate', self.open_dir_callback)
+        self.action_play_one = gtk.Action('play_one', _('Play One'), _('Play one file'), gtk.STOCK_FILE)
+        self.action_play_one.connect('activate', self.play_one_callback)
         self.action_save = gtk.Action('save', _('Save Playlist'), _('Save current playlist to file'), gtk.STOCK_SAVE_AS)
         self.action_save.connect('activate', self.save_to_playlist_callback)
         self.action_empty_playlist = gtk.Action('empty_playlist', _('Clear Playlist'), _('Clear current playlist'), gtk.STOCK_DELETE)
@@ -202,32 +185,40 @@ class PanucciGUI(object):
         self.action_settings.connect('activate', self.settings_callback)
         self.action_timer = gtk.Action('timer', _('Sleep Timer'), _('Start a timed shutdown'), None)
         self.action_timer.connect('activate', self.create_timer_dialog)
+        self.action_fm = gtk.Action('fm', _('FM Transmitter'), _('Show FM transmitter dialog'), None)
+        self.action_fm.connect('activate', self.show_fm_transmitter)
         # Settings menu
-        self.action_lock_progress = gtk.ToggleAction('lock_progress', 'Lock Progress Bar', None, None)
+        self.action_lock_progress = gtk.ToggleAction('lock_progress', _('Lock Progress Bar'), None, None)
         self.action_lock_progress.connect("activate", self.set_boolean_config_callback)
         self.action_lock_progress.set_active(self.config.getboolean("options", "lock_progress"))
-        self.action_dual_action_button = gtk.ToggleAction('dual_action_button', 'Dual Action Button', None, None)
+        self.action_dual_action_button = gtk.ToggleAction('dual_action_button', _('Dual Action Button'), None, None)
         self.action_dual_action_button.connect("activate", self.set_boolean_config_callback)
         self.action_dual_action_button.set_active(self.config.getboolean("options", "dual_action_button"))
-        self.action_stay_at_end = gtk.ToggleAction('stay_at_end', 'Stay at End', None, None)
+        self.action_stay_at_end = gtk.ToggleAction('stay_at_end', _('Stay at End'), None, None)
         self.action_stay_at_end.connect("activate", self.set_boolean_config_callback)
         self.action_stay_at_end.set_active(self.config.getboolean("options", "stay_at_end"))
-        self.action_seek_back = gtk.ToggleAction('seek_back', 'Seek Back', None, None)
+        self.action_seek_back = gtk.ToggleAction('seek_back', _('Seek Back'), None, None)
         self.action_seek_back.connect("activate", self.set_boolean_config_callback)
         self.action_seek_back.set_active(self.config.getboolean("options", "seek_back"))
-        self.action_scrolling_labels = gtk.ToggleAction('scrolling_labels', 'Scrolling Labels', None, None)
+        self.action_scrolling_labels = gtk.ToggleAction('scrolling_labels', _('Scrolling Labels'), None, None)
         self.action_scrolling_labels.connect("activate", self.scrolling_labels_callback)
         self.action_scrolling_labels.set_active(self.config.getboolean("options", "scrolling_labels"))
-        self.action_play_mode = gtk.Action('play_mode', 'Play Mode', None, None)
-        self.action_play_mode_all = gtk.RadioAction('all', 'All', None, None, 0)
+        self.action_resume_all = gtk.ToggleAction('resume_all', _('Resume All'), None, None)
+        self.action_resume_all.connect("activate", self.resume_all_callback)
+        self.action_resume_all.set_active(self.config.getboolean("options", "resume_all"))
+        self.action_play_on_headset = gtk.ToggleAction('play_on_headset', _('Play on Headset'), None, None)
+        self.action_play_on_headset.connect("activate", self.set_boolean_config_callback)
+        self.action_play_on_headset.set_active(self.config.getboolean("options", "play_on_headset"))
+        self.action_play_mode = gtk.Action('play_mode', _('Play Mode'), None, None)
+        self.action_play_mode_all = gtk.RadioAction('all', _('All'), None, None, 0)
         self.action_play_mode_all.connect("activate", self.set_play_mode_callback)
-        self.action_play_mode_single = gtk.RadioAction('single', 'Single', None, None, 1)
+        self.action_play_mode_single = gtk.RadioAction('single', _('Single'), None, None, 1)
         self.action_play_mode_single.connect("activate", self.set_play_mode_callback)
         self.action_play_mode_single.set_group(self.action_play_mode_all)
-        self.action_play_mode_random = gtk.RadioAction('random', 'Random', None, None, 1)
+        self.action_play_mode_random = gtk.RadioAction('random', _('Random'), None, None, 1)
         self.action_play_mode_random.connect("activate", self.set_play_mode_callback)
         self.action_play_mode_random.set_group(self.action_play_mode_all)
-        self.action_play_mode_repeat = gtk.RadioAction('repeat', 'Repeat', None, None, 1)
+        self.action_play_mode_repeat = gtk.RadioAction('repeat', _('Repeat'), None, None, 1)
         self.action_play_mode_repeat.connect("activate", self.set_play_mode_callback)
         self.action_play_mode_repeat.set_group(self.action_play_mode_all)
         if self.config.get("options", "play_mode") == "single":
@@ -247,6 +238,7 @@ class PanucciGUI(object):
         file_menu = gtk.Menu()
         file_menu.append(self.action_open.create_menu_item())
         file_menu.append(self.action_open_dir.create_menu_item())
+        file_menu.append(self.action_play_one.create_menu_item())
         file_menu.append(self.action_save.create_menu_item())
         file_menu.append(self.action_empty_playlist.create_menu_item())
         file_menu.append(self.action_delete_bookmarks.create_menu_item())
@@ -259,7 +251,7 @@ class PanucciGUI(object):
         tools_menu = gtk.Menu()
         tools_menu.append(self.action_playlist.create_menu_item())
         tools_menu.append(self.action_timer.create_menu_item())
-        #tools_menu.append(self.action_settings.create_menu_item())
+        #tools_menu.append(self.action_fm.create_menu_item())
         tools_menu_item.set_submenu(tools_menu)
         menu_bar.append(tools_menu_item)
 
@@ -270,6 +262,7 @@ class PanucciGUI(object):
         settings_menu.append(self.action_stay_at_end.create_menu_item())
         settings_menu.append(self.action_seek_back.create_menu_item())
         settings_menu.append(self.action_scrolling_labels.create_menu_item())
+        settings_menu.append(self.action_resume_all.create_menu_item())
         play_mode_menu_item = self.action_play_mode.create_menu_item()
         settings_menu.append(play_mode_menu_item)
         play_mode_menu = gtk.Menu()
@@ -306,8 +299,10 @@ class PanucciGUI(object):
                 self.action_playlist,
                 self.action_open,
                 self.action_open_dir,
+                self.action_play_one,
                 self.action_empty_playlist,
                 self.action_timer,
+                self.action_fm,
                 self.action_about):
             b = gtk.Button()
             action.connect_proxy(b)
@@ -492,6 +487,12 @@ class PanucciGUI(object):
         if filename is not None:
             self._play_file(filename)
 
+    def play_one_callback(self, widget=None):
+        filename = gtkutil.get_file_from_filechooser(self)
+        if filename is not None:
+            self.empty_playlist_callback(None)
+            self._play_file(filename)
+
     def save_to_playlist_callback(self, widget=None):
         filename = gtkutil.get_file_from_filechooser(
             self, save_file=True, save_to='playlist.m3u' )
@@ -554,6 +555,11 @@ class PanucciGUI(object):
         self.set_boolean_config_callback(w)
         self.__player_tab.title_label.scrolling = w.get_active()
 
+    def resume_all_callback(self, w):
+        self.set_boolean_config_callback(w)
+        if not w.get_active():
+            self.playlist.reset_all_seek_to()
+
     def set_play_mode_callback(self, w):
         self.config.set("options", "play_mode", w.get_name())
 
@@ -602,6 +608,12 @@ class PanucciGUI(object):
             from panucci.gtkui.gtkaboutdialog import AboutDialog
             AboutDialog(self.main_window, panucci.__version__)
 
+    def show_fm_transmitter(self, ws):
+        import osso
+        ctx = osso.Context('Panucci', '1.3.3.7', False)
+        plugin = osso.Plugin(ctx)
+        plugin.plugin_execute('libcpfmtx.so', True)
+
     def _play_file(self, filename, pause_on_load=False):
         self.playlist.load( os.path.abspath(filename) )
 
@@ -610,7 +622,24 @@ class PanucciGUI(object):
 
     def handle_headset_button(self, event, button):
         if event == 'ButtonPressed' and button == 'phone':
-            self.playlist.player.play_pause_toggle()
+            self.playlist.play_pause_toggle()
+
+    def handle_connection_state(self, device_path):
+        PATH = '/org/freedesktop/Hal/devices/computer_logicaldev_input_1'
+        if device_path == PATH and self.config.getboolean("options", "play_on_headset") and not self.playlist.playing:
+            self.playlist.play_pause_toggle()
+
+    def handle_bt_button(self, signal, button):
+        # See http://bugs.maemo.org/8283 for details
+        if signal == 'ButtonPressed':
+            if button == 'play-cd':
+                self.playlist.play_pause_toggle()
+            elif button == 'pause-cd':
+                self.playlist.play_pause_toggle()
+            elif button == 'next-song':
+                self.__player_tab.do_seek(self.config.getint("options", "seek_short"))
+            elif button == 'previous-song':
+                self.__player_tab.do_seek(-1*self.config.getint("options", "seek_short"))
 
     def __select_current_item( self ):
         # Select the currently playing track in the playlist tab
@@ -631,36 +660,24 @@ class PlayerTab(ObservableService, gtk.HBox):
         self.__gui_root = gui_root
         self.config = gui_root.config
         self.playlist = gui_root.playlist
+        self.metadata = None
 
         gtk.HBox.__init__(self)
         ObservableService.__init__(self, self.signals, self.__log)
 
-        # Timers
         self.progress_timer_id = None
-
         self.recent_files = []
         self.make_player_tab()
         self.has_coverart = False
+        self.reset_progress()
 
-        #settings.register( 'enable_dual_action_btn_changed',
-        #                   self.on_dual_action_setting_changed )
-        #settings.register( 'dual_action_button_delay_changed',
-        #                   self.on_dual_action_setting_changed )
-        #settings.register( 'scrolling_labels_changed', lambda v:
-        #                   setattr( self.title_label, 'scrolling', v ) )
-
-        self.playlist.player.register( 'stopped', self.on_player_stopped )
-        self.playlist.player.register( 'playing', self.on_player_playing )
-        self.playlist.player.register( 'paused', self.on_player_paused )
-        #self.playlist.player.register( 'eof', self.on_player_eof )
-        self.playlist.register( 'end-of-playlist',
-                                  self.on_player_end_of_playlist )
-        self.playlist.register( 'new-track-loaded',
-                                  self.on_player_new_track )
-        self.playlist.register( 'new-metadata-available',
-                                  self.on_player_new_metadata )
-        self.playlist.register( 'reset-playlist',
-                                  self.on_player_reset_playlist )
+        self.playlist.register('stopped', self.on_player_stopped)
+        self.playlist.register('playing', self.on_player_playing)
+        self.playlist.register('paused', self.on_player_paused )
+        self.playlist.register('end-of-playlist', self.on_player_end_of_playlist)
+        self.playlist.register('new-track-loaded', self.on_player_new_track)
+        self.playlist.register('new-metadata-available', self.on_player_new_metadata)
+        self.playlist.register('reset-playlist', self.on_player_reset_playlist )
 
     def make_player_tab(self):
         main_vbox = gtk.VBox()
@@ -673,8 +690,11 @@ class PlayerTab(ObservableService, gtk.HBox):
         metadata_hbox.set_spacing(6)
         main_vbox.pack_start(metadata_hbox, True, False)
 
+        event_box = gtk.EventBox()
         self.cover_art = gtk.Image()
-        metadata_hbox.pack_start( self.cover_art, False, False )
+        event_box.add(self.cover_art)
+        metadata_hbox.pack_start(event_box, False, False)
+        event_box.connect('button-press-event', self.cover_art_callback)
 
         # vbox to hold metadata
         metadata_vbox = gtk.VBox()
@@ -730,7 +750,7 @@ class PlayerTab(ObservableService, gtk.HBox):
         self.rrewind_button = create_da(
                 gtkutil.generate_image('media-skip-backward.png'),
                 lambda: self.do_seek(-1*self.config.getint('options', 'seek_long')),
-                gtkutil.generate_image(gtk.STOCK_GOTO_FIRST, True),
+                gtkutil.generate_image("gtk-goto-first-ltr.png"),
                 self.playlist.prev)
         buttonbox.add(self.rrewind_button)
 
@@ -743,7 +763,6 @@ class PlayerTab(ObservableService, gtk.HBox):
         gtkutil.image(self.play_pause_button, 'media-playback-start.png')
         self.play_pause_button.connect( 'clicked',
                                         self.on_btn_play_pause_clicked )
-        self.play_pause_button.set_sensitive(False)
         buttonbox.add(self.play_pause_button)
 
         self.forward_button = create_da(
@@ -754,13 +773,13 @@ class PlayerTab(ObservableService, gtk.HBox):
         self.fforward_button = create_da(
                 gtkutil.generate_image('media-skip-forward.png'),
                 lambda: self.do_seek(self.config.getint('options', 'seek_long')),
-                gtkutil.generate_image(gtk.STOCK_GOTO_LAST, True),
+                gtkutil.generate_image("gtk-goto-last-ltr.png"),
                 self.playlist.next)
         buttonbox.add(self.fforward_button)
 
         self.bookmarks_button = create_da(
                 gtkutil.generate_image('bookmark-new.png'),
-                self.playlist.player.add_bookmark_at_current_position,
+                self.playlist.add_bookmark_at_current_position,
                 gtkutil.generate_image(gtk.STOCK_JUMP_TO, True),
                 lambda *args: self.notify('select-current-item-request'))
         buttonbox.add(self.bookmarks_button)
@@ -789,6 +808,7 @@ class PlayerTab(ObservableService, gtk.HBox):
                 w.unset_flags(gtk.CAN_FOCUS)
 
     def set_controls_sensitivity(self, sensitive):
+        return
         for button in self.forward_button, self.rewind_button, \
                       self.fforward_button, self.rrewind_button:
 
@@ -819,8 +839,12 @@ class PlayerTab(ObservableService, gtk.HBox):
         self.stop_progress_timer()
         self.set_controls_sensitivity(False)
         gtkutil.image(self.play_pause_button, 'media-playback-start.png')
+        if self.metadata:
+            estimated_length = self.metadata.get('length', 0)
+            self.set_progress_callback( 0, estimated_length )
 
     def on_player_playing(self):
+        self.progress_timer_callback()
         self.start_progress_timer()
         gtkutil.image(self.play_pause_button, 'media-playback-pause.png')
         self.set_controls_sensitivity(True)
@@ -839,12 +863,9 @@ class PlayerTab(ObservableService, gtk.HBox):
     def on_player_new_metadata(self):
         self.metadata = self.playlist.get_file_metadata()
         self.set_metadata(self.metadata)
-
-        if not self.playlist.player.playing:
-            position = self.playlist.get_current_position()
-            estimated_length = self.metadata.get('length', 0)
-            self.set_progress_callback( position, estimated_length )
-            self.playlist.player.set_position_duration(position, 0)
+        position = self.playlist.get_current_position()
+        estimated_length = self.metadata.get('length', 0)
+        self.set_progress_callback(position, estimated_length)
 
     def on_player_paused( self, position, duration ):
         self.stop_progress_timer() # This should save some power
@@ -853,10 +874,8 @@ class PlayerTab(ObservableService, gtk.HBox):
 
     def on_player_end_of_playlist(self, loop):
         if not loop:
-            self.playlist.player.stop_end_of_playlist()
             estimated_length = self.metadata.get('length', 0)
             self.set_progress_callback( 0, estimated_length )
-            self.playlist.player.set_position_duration(0, 0)
 
     def on_player_reset_playlist(self):
         self.on_player_stopped()
@@ -864,7 +883,6 @@ class PlayerTab(ObservableService, gtk.HBox):
         self.reset_progress()
 
     def reset_progress(self):
-        self.progress.set_fraction(0)
         self.set_progress_callback(0,0)
         self.__gui_root.main_window.set_title("Panucci")
 
@@ -880,20 +898,23 @@ class PlayerTab(ObservableService, gtk.HBox):
         if ( not self.config.getboolean("options", "lock_progress") and
                 event.type == gtk.gdk.BUTTON_PRESS and event.button == 1 ):
             new_fraction = event.x/float(widget.get_allocation().width)
-            resp = self.playlist.player.do_seek(percent=new_fraction)
+            resp = self.playlist.do_seek(percent=new_fraction)
             if resp:
                 # Preemptively update the progressbar to make seeking smoother
                 self.set_progress_callback( *resp )
 
     def on_btn_play_pause_clicked(self, widget=None):
-        self.playlist.player.play_pause_toggle()
+        self.playlist.play_pause_toggle()
+
+    def cover_art_callback(self, widget, event):
+        self.on_btn_play_pause_clicked(widget)
 
     def progress_timer_callback( self ):
-        if self.playlist.player.playing and not self.playlist.player.seeking:
-            pos_int, dur_int = self.playlist.player.get_position_duration()
+        if self.playlist.playing and not self.playlist.seeking:
+            pos_int, dur_int = self.playlist.get_position_duration()
             # This prevents bogus values from being set while seeking
-            if ( pos_int > 10**9 ) and ( dur_int > 10**9 ):
-                self.set_progress_callback( pos_int, dur_int )
+            if pos_int >= 0 and dur_int >= 0:
+                self.set_progress_callback(pos_int, dur_int)
         return True
 
     def start_progress_timer( self ):
@@ -952,9 +973,9 @@ class PlayerTab(ObservableService, gtk.HBox):
                     _str = cgi.escape(value)
                 elif tag == "title":
                     _str = '<b><big>' + cgi.escape(value) + '</big></b>'
-                    if not platform.MAEMO:
+                    if not platform.HANDSET:
                         value += ' - Panucci'
-                    if platform.FREMANTLE and len(value) > 25:
+                    elif len(value) > 25:
                         value = value[:24] + '...'
                     self.__gui_root.main_window.set_title( value )
                 
@@ -966,7 +987,7 @@ class PlayerTab(ObservableService, gtk.HBox):
                 tags[tag].show()
 
     def do_seek(self, seek_amount):
-        resp = self.playlist.do_seek(seek_amount*10**9)
+        resp = self.playlist.do_seek(from_current=seek_amount*10**9)
         if resp:
             # Preemptively update the progressbar to make seeking smoother
             self.set_progress_callback( *resp )
